@@ -19,8 +19,9 @@
 
 {% macro glue__drop_relation(relation) -%}
   {% call statement('drop_relation', auto_begin=False) -%}
-    {%- if relation.type is not none %}
-        drop {{ relation.type }} if exists {{ relation }}
+  {% set rel_type = adapter.get_table_type(relation)  %}
+    {%- if rel_type is not none %}
+        drop {{ rel_type }} if exists {{ relation }}
     {%- else -%}
         drop table if exists {{ relation }}
     {%- endif %}
@@ -38,12 +39,21 @@
     {{ sql }}
 {% endmacro %}
 
+{% macro glue__file_format_clause() %}
+  {%- set file_format = config.get('file_format', validator=validation.any[basestring]) -%}
+  {%- if file_format is not none %}
+    using {{ file_format }}
+  {%- else -%}
+    using PARQUET
+  {%- endif %}
+{%- endmacro -%}
+
 {% macro glue__create_table_as(temporary, relation, sql) -%}
   {% if temporary -%}
     {{ create_temporary_view(relation, sql) }}
   {%- else -%}
     create table {{ relation }}
-    {{ file_format_clause() }}
+    {{ glue__file_format_clause() }}
     {{ partition_cols(label="partitioned by") }}
     {{ clustered_cols(label="clustered by") }}
     {{ glue__location_clause(relation) }}
@@ -53,6 +63,14 @@
   {%- endif %}
 {%- endmacro -%}
 
+{% macro glue__create_tmp_table_as(relation, sql) -%}
+  {% call statement("create_tmp_table_as", fetch_result=false, auto_begin=false) %}
+    create table {{ relation }}
+    as
+      {{ sql }}
+  {% endcall %}
+{%- endmacro -%}
+
 {% macro glue__snapshot_get_time() -%}
   datetime()
 {%- endmacro %}
@@ -104,4 +122,8 @@
   {% call statement("run_query_statement", fetch_result=false, auto_begin=false) %}
     {{ sql }}
   {% endcall %}
-{% endmacro %}
\ No newline at end of file
+{% endmacro %}
+
+{% macro spark__type_string() -%}
+    STRING
+{%- endmacro %}
\ No newline at end of file
